from setuptools import setup

setup(name='knct_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions'],
      author='Saurabh Sharma',
      author_email='srbh453@gmail.com',
      zip_safe=False)